==> myfaces-tobago-1.5.13-source-release.zip: tobago-1.5.13/tobago-example/tobago-example-test/src/main/java/org/apache/myfaces/tobago/example/test/Tobago1134.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.example.test;

import org.apache.myfaces.tobago.config.Configurable;
import org.apache.myfaces.tobago.context.Markup;
import org.apache.myfaces.tobago.context.ResourceManagerUtils;
import org.apache.myfaces.tobago.layout.Measure;

import javax.faces.context.FacesContext;

public class Tobago1134 {

  /**
   * Tests TOBAGO-1134
   */
  public Measure getValue() {

    Configurable c = new Configurable() {
      public String getRendererType() {
        return "Test";
      }

      public Markup getCurrentMarkup() {
        return Markup.valueOf("test");
      }
    };

    final Measure value = ResourceManagerUtils.getThemeMeasure(FacesContext.getCurrentInstance(), c, "testValue");

    return value;
  }

}

==> myfaces-tobago-2.5.1-source-release.zip: tobago-2.5.1/tobago-example/tobago-example-test/src/main/java/org/apache/myfaces/tobago/example/test/Tobago1134.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.example.test;

import org.apache.myfaces.tobago.config.Configurable;
import org.apache.myfaces.tobago.context.Markup;
import org.apache.myfaces.tobago.context.ResourceManagerUtils;
import org.apache.myfaces.tobago.layout.Measure;

import javax.faces.context.FacesContext;

public class Tobago1134 {

  /**
   * Tests TOBAGO-1134
   */
  public Measure getValue() {

    final Configurable c = new Configurable() {
      public String getRendererType() {
        return "Test";
      }

      public Markup getCurrentMarkup() {
        return Markup.valueOf("test");
      }
    };

    final Measure value = ResourceManagerUtils.getThemeMeasure(FacesContext.getCurrentInstance(), c, "testValue");

    return value;
  }

}
